(function ($, Drupal, drupalSettings, once) {
  Drupal.behaviors.zoomVideoBehavior = {
    attach: function (context, settings) {
      const client = ZoomMtgEmbedded.createClient();
      const zoomVideo = drupalSettings.zoom_video;
      let meetingSDKElement = document.getElementById('meetingSDKElement');
      let authEndpoint = '/zoom_video/endpoint';
      // Getting SDK Key from zoom_configuration_form's data.
      let sdkKey = zoomVideo.sdk_key;
      let meetingNumber;
      let meetingPassword;
      // Getting logged in Drupal user's name and email
      let meetingUserName = drupalSettings.user.name;
      let meetingUserEmail = drupalSettings.user.email;
      let registrantToken = '';
      let zakToken = '';
      let role = 0;

      function logInfo(info) {
        console.log(info);
      }

      function logError(error) {
        console.log('Error', error);
      }

      async function initializeAndJoinMeeting(signature) {
        try {
          await client.init({ zoomAppRoot: meetingSDKElement, language: 'en-US' });
          await client.join({
            signature: signature,
            sdkKey: sdkKey,
            meetingNumber: meetingNumber,
            password: meetingPassword,
            userName: meetingUserName,
            userEmail: meetingUserEmail,
            tk: registrantToken,
            zak: zakToken,
          });
          logInfo('joined successfully');
        } catch (error) {
          logError(error);
        }
      }

      function getSignature() {
        return fetch(authEndpoint, {
          method: 'POST',
          headers: {
            'Content-Type': 'application/json',
          },
          body: JSON.stringify({
            meetingNumber: meetingNumber,
            role: role,
          }),
        }).then((response) => {
          logInfo(response);
          return response.json();
        }).catch((error) => {
          logError(error);
        });
      }

      $(once('zoomVideoWidget', '.join-meeting', context)).click(async function () {
        $(this).addClass('hidden');
        const { signature } = await getSignature();
        await initializeAndJoinMeeting(signature);
      });
    },
  };
})(jQuery, Drupal, drupalSettings, once);
