<?php

namespace Drupal\zoom_video\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'zoom_video_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "zoom_video_formatter",
 *   label = @Translation("Zoom Video Formatter"),
 *   field_types = {
 *     "zoom_video_field"
 *   }
 * )
 */
class ZoomVideoFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $element = [];

    foreach ($items as $delta => $item) {
      $meeting_number = $item->get('meeting_number')->getValue();
      $meeting_password = $item->get('password')->getValue();

      $element[$delta] = [
        '#type' => 'html_tag',
        '#tag' => 'button',
        '#value' => $this->t('Join Meeting'),
        '#attributes' => [
          'class' => ['join-meeting'],
          'data-meeting-number' => $meeting_number,
          'data-meeting-password' => $meeting_password,
        ],
        '#attached' => [
          'library' => ['zoom_video/zoom-sdk-js-library'],
        ],
      ];
    }

    return $element;
  }

}
